# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='groups.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cgroups.proto\x12\x06\x64ialog\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x15scalapb/scalapb.proto\"\xf2\x01\n\x06Member\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\ninvited_at\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x05 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x06 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12=\n\ndeleted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\x8a\xea\x30\t\n\x07visibleJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05\"\xe6\x02\n\x05Group\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1f\n\x04\x64\x61ta\x18\x1d \x01(\x0b\x32\x11.dialog.GroupData\x12#\n\x0bself_member\x18\x1e \x01(\x0b\x32\x0e.dialog.Member\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x34\n\ngroup_type\x18\x19 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12>\n\tshortname\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visibleJ\x04\x08\x04\x10\x05J\x04\x08\x18\x10\x19J\x04\x08\x06\x10\x07J\x04\x08\x14\x10\x15J\x04\x08\x1a\x10\x1bJ\x04\x08\x10\x10\x11J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13J\x04\x08\x1c\x10\x1d\"\xf0\x05\n\tGroupData\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12-\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12%\n\x0emembers_amount\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\ngroup_type\x18\x05 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12$\n\rowner_user_id\x18\x06 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12=\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12>\n\tshortname\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x45\n\x10\x62\x61se_permissions\x18\n \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x0b \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\tpinned_at\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x0f\x63onference_link\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x13members_count_limit\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12/\n\ndeleted_at\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x80\x03\n\x10GroupPartialInfo\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x04type\x18\x04 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07\x63ompact\x12>\n\tshortname\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x07 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12#\n\x0bself_member\x18\x08 \x01(\x0b\x32\x0e.dialog.Member\x12.\n\tpinned_at\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\":\n\x0bUpdateGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1f\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x11.dialog.GroupData\"\xbe\x01\n\x12RequestLoadMembers\x12\x32\n\x05group\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\x04next\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa0\x01\n\x13ResponseLoadMembers\x12:\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07\x63ompact\x12.\n\x07members\x18\x03 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"W\n\x17UpdateGroupTitleChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"j\n\x18UpdateGroupAvatarChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x02 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07visible\"u\n\x17UpdateGroupAboutChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"Z\n\x17UpdateGroupOwnerChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x8b\x01\n!UpdateGroupBasePermissionsChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x45\n\x10\x62\x61se_permissions\x18\x02 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\"l\n\x19UpdateGroupMembersUpdated\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\"\x99\x01\n\x15UpdateGroupMemberDiff\x12$\n\rremoved_users\x18\x01 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\radded_members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\x12$\n\rmembers_count\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"g\n\x1eUpdateGroupMembersCountChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\rmembers_count\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xc1\x03\n\x12RequestCreateGroup\x12\x1a\n\x03rid\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x08space_id\x18\t \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x31\n\x05users\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\ngroup_type\x18\x06 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x08username\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x07 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible\x12\x45\n\x10\x62\x61se_permissions\x18\n \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9d\x01\n\x13ResponseCreateGroup\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12\x1c\n\x05group\x18\x03 \x01(\x0b\x32\r.dialog.Group\x12\'\n\nuser_peers\x18\x05 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x04\x10\x05\"\xe9\x01\n\x15RequestEditGroupTitle\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8d\x01\n\x18RequestSetGroupShortname\x12\x31\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tshortname\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x89\x02\n\x16RequestEditGroupAvatar\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\rfile_location\x18\x03 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07\x63ompact\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa2\x01\n\x17ResponseEditGroupAvatar\x12\x1e\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0e.dialog.Avatar\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\x03\x12\x1e\n\x03mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xcf\x01\n\x18RequestRemoveGroupAvatar\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x87\x02\n\x15RequestEditGroupAbout\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xae\x02\n\x1fRequestEditGroupBasePermissions\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\trandom_id\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12H\n\x13granted_permissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\x12H\n\x13revoked_permissions\x18\x04 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc0\x02\n\x1cRequestEditMemberPermissions\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\tuser_peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12H\n\x13granted_permissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\x12H\n\x13revoked_permissions\x18\x04 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"O\n\x0eResponseMember\x12\x1e\n\x06member\x18\x01 \x01(\x0b\x32\x0e.dialog.Member:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xfa\x01\n\x11RequestInviteUser\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x04user\x18\x03 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc8\x01\n\x11RequestLeaveGroup\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf8\x01\n\x0fRequestKickUser\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x04user\x18\x03 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xe6\x01\n\x14RequestMakeUserAdmin\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\tuser_peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"x\n\x15GroupMemberPermission\x12\x1e\n\x07user_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0bpermissions\x18\x02 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\x0c\x8a\xea\x30\x08\n\x06hidden\"\x82\x01\n RequestGetGroupMemberPermissions\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08user_ids\x18\x02 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"v\n!ResponseGetGroupMemberPermissions\x12\x32\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1d.dialog.GroupMemberPermission:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa8\x01\n#UpdateGroupMemberPermissionsChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\"\x93\x01\n\x18RequestTransferOwnership\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tnew_owner\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"?\n\x11ResponseInviteUrl\x12\x0b\n\x03url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"q\n\x18RequestGetGroupInviteUrl\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"<\n\x1cRequestGetGroupInviteUrlBase:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"K\n\x1dResponseGetGroupInviteUrlBase\x12\x0b\n\x03url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"o\n\x16RequestRevokeInviteUrl\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8f\x01\n\x10RequestJoinGroup\x12\x1c\n\x05token\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12?\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc9\x01\n\x11ResponseJoinGroup\x12\x1c\n\x05group\x18\x01 \x01(\x0b\x32\r.dialog.Group\x12\'\n\nuser_peers\x18\x07 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12\x1e\n\x03mid\x18\x08 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x05\x10\x06\"i\n\x16RequestJoinGroupByPeer\x12\x31\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"S\n\x12RequestDeleteGroup\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"X\n\x1aRequestGetGroupPartialInfo\x12\x1c\n\x05token\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"[\n\x18UpdateGroupMemberInvited\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x06member\x18\x02 \x01(\x0b\x32\x0e.dialog.Member\"\xb8\x01\n\x19UpdateGroupInviteObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\t \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\n \x01(\x0b\x32\x11.dialog.UUIDValue\x12!\n\ninvite_uid\x18\x05 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x08 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xe9\x01\n\x1eUpdateGroupUserInvitedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0binviter_uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\x98\x01\n\x1cUpdateGroupUserLeaveObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xba\x01\n\x1bUpdateGroupUserKickObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nkicker_uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"s\n UpdateGroupMembersUpdateObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\"\xb8\x01\n\x1fUpdateGroupTitleChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"}\n\x1fUpdateGroupAboutChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"\xcb\x01\n UpdateGroupAvatarChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"|\n\x1bUpdateGroupShortnameChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tshortname\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible*d\n\tGroupType\x12\x15\n\x11GROUPTYPE_UNKNOWN\x10\x00\x12\x13\n\x0fGROUPTYPE_GROUP\x10\x01\x12\x15\n\x11GROUPTYPE_CHANNEL\x10\x02\x12\x14\n\x10GROUPTYPE_THREAD\x10\x04*\xec\x04\n\x14GroupAdminPermission\x12 \n\x1cGROUPADMINPERMISSION_UNKNOWN\x10\x00\x12&\n\"GROUPADMINPERMISSION_EDITSHORTNAME\x10\x01\x12\x1f\n\x1bGROUPADMINPERMISSION_INVITE\x10\x02\x12\x1d\n\x19GROUPADMINPERMISSION_KICK\x10\x03\x12#\n\x1fGROUPADMINPERMISSION_UPDATEINFO\x10\x04\x12\'\n#GROUPADMINPERMISSION_SETPERMISSIONS\x10\x05\x12$\n GROUPADMINPERMISSION_EDITMESSAGE\x10\x06\x12&\n\"GROUPADMINPERMISSION_DELETEMESSAGE\x10\x07\x12,\n(GROUPADMINPERMISSION_GETINTEGRATIONTOKEN\x10\x08\x12$\n GROUPADMINPERMISSION_SENDMESSAGE\x10\t\x12#\n\x1fGROUPADMINPERMISSION_PINMESSAGE\x10\n\x12$\n GROUPADMINPERMISSION_VIEWMEMBERS\x10\x0b\x12\x1e\n\x1aGROUPADMINPERMISSION_LEAVE\x10\x0c\x12\"\n\x1eGROUPADMINPERMISSION_TARGETING\x10\r\x12\x1f\n\x1bGROUPADMINPERMISSION_DELETE\x10\x0e\x12*\n&GROUPADMINPERMISSION_MANAGE_CONFERENCE\x10\x0f\x32\xa6\x15\n\x06Groups\x12n\n\x0bLoadMembers\x12\x1a.dialog.RequestLoadMembers\x1a\x1b.dialog.ResponseLoadMembers\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Groups/LoadMembers:\x01*\x12n\n\x0b\x43reateGroup\x12\x1a.dialog.RequestCreateGroup\x1a\x1b.dialog.ResponseCreateGroup\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Groups/CreateGroup:\x01*\x12v\n\x0e\x45\x64itGroupTitle\x12\x1d.dialog.RequestEditGroupTitle\x1a\x1a.dialog.ResponseSeqDateMid\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/EditGroupTitle:\x01*\x12x\n\x11SetGroupShortname\x12 .dialog.RequestSetGroupShortname\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/SetGroupShortname:\x01*\x12~\n\x0f\x45\x64itGroupAvatar\x12\x1e.dialog.RequestEditGroupAvatar\x1a\x1f.dialog.ResponseEditGroupAvatar\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/EditGroupAvatar:\x01*\x12\x7f\n\x11RemoveGroupAvatar\x12 .dialog.RequestRemoveGroupAvatar\x1a\x1a.dialog.ResponseSeqDateMid\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/RemoveGroupAvatar:\x01*\x12s\n\x0e\x45\x64itGroupAbout\x12\x1d.dialog.RequestEditGroupAbout\x1a\x17.dialog.ResponseSeqDate\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/EditGroupAbout:\x01*\x12\x90\x01\n\x18\x45\x64itGroupBasePermissions\x12\'.dialog.RequestEditGroupBasePermissions\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Groups/EditGroupBasePermissions:\x01*\x12j\n\nInviteUser\x12\x19.dialog.RequestInviteUser\x1a\x1a.dialog.ResponseSeqDateMid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Groups/InviteUser:\x01*\x12j\n\nLeaveGroup\x12\x19.dialog.RequestLeaveGroup\x1a\x1a.dialog.ResponseSeqDateMid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Groups/LeaveGroup:\x01*\x12\x64\n\x08KickUser\x12\x17.dialog.RequestKickUser\x1a\x1a.dialog.ResponseSeqDateMid\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/grpc/Groups/KickUser:\x01*\x12p\n\rMakeUserAdmin\x12\x1c.dialog.RequestMakeUserAdmin\x1a\x17.dialog.ResponseSeqDate\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Groups/MakeUserAdmin:\x01*\x12\xa6\x01\n\x19GetGroupMemberPermissions\x12(.dialog.RequestGetGroupMemberPermissions\x1a).dialog.ResponseGetGroupMemberPermissions\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Groups/GetGroupMemberPermissions:\x01*\x12\x87\x01\n\x15\x45\x64itMemberPermissions\x12$.dialog.RequestEditMemberPermissions\x1a\x16.dialog.ResponseMember\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Groups/EditMemberPermissions:\x01*\x12|\n\x11TransferOwnership\x12 .dialog.RequestTransferOwnership\x1a\x17.dialog.ResponseSeqDate\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/TransferOwnership:\x01*\x12~\n\x11GetGroupInviteUrl\x12 .dialog.RequestGetGroupInviteUrl\x1a\x19.dialog.ResponseInviteUrl\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/GetGroupInviteUrl:\x01*\x12\x96\x01\n\x15GetGroupInviteUrlBase\x12$.dialog.RequestGetGroupInviteUrlBase\x1a%.dialog.ResponseGetGroupInviteUrlBase\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Groups/GetGroupInviteUrlBase:\x01*\x12x\n\x0fRevokeInviteUrl\x12\x1e.dialog.RequestRevokeInviteUrl\x1a\x19.dialog.ResponseInviteUrl\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/RevokeInviteUrl:\x01*\x12\x66\n\tJoinGroup\x12\x18.dialog.RequestJoinGroup\x1a\x19.dialog.ResponseJoinGroup\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/grpc/Groups/JoinGroup:\x01*\x12s\n\x0fJoinGroupByPeer\x12\x1e.dialog.RequestJoinGroupByPeer\x1a\x14.dialog.ResponseVoid\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/JoinGroupByPeer:\x01*\x12i\n\x0b\x44\x65leteGroup\x12\x1a.dialog.RequestDeleteGroup\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Groups/DeleteGroup:\x01*\x12\x84\x01\n\x13GetGroupPartialInfo\x12\".dialog.RequestGetGroupPartialInfo\x1a\x18.dialog.GroupPartialInfo\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Groups/GetGrpoupPartialInfo:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_GROUPTYPE = _descriptor.EnumDescriptor(
  name='GroupType',
  full_name='dialog.GroupType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_GROUP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_CHANNEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_THREAD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10265,
  serialized_end=10365,
)
_sym_db.RegisterEnumDescriptor(_GROUPTYPE)

GroupType = enum_type_wrapper.EnumTypeWrapper(_GROUPTYPE)
_GROUPADMINPERMISSION = _descriptor.EnumDescriptor(
  name='GroupAdminPermission',
  full_name='dialog.GroupAdminPermission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_EDITSHORTNAME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_INVITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_KICK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_UPDATEINFO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_SETPERMISSIONS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_EDITMESSAGE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_DELETEMESSAGE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_GETINTEGRATIONTOKEN', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_SENDMESSAGE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_PINMESSAGE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_VIEWMEMBERS', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_LEAVE', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_TARGETING', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_DELETE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_MANAGE_CONFERENCE', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10368,
  serialized_end=10988,
)
_sym_db.RegisterEnumDescriptor(_GROUPADMINPERMISSION)

GroupAdminPermission = enum_type_wrapper.EnumTypeWrapper(_GROUPADMINPERMISSION)
GROUPTYPE_UNKNOWN = 0
GROUPTYPE_GROUP = 1
GROUPTYPE_CHANNEL = 2
GROUPTYPE_THREAD = 4
GROUPADMINPERMISSION_UNKNOWN = 0
GROUPADMINPERMISSION_EDITSHORTNAME = 1
GROUPADMINPERMISSION_INVITE = 2
GROUPADMINPERMISSION_KICK = 3
GROUPADMINPERMISSION_UPDATEINFO = 4
GROUPADMINPERMISSION_SETPERMISSIONS = 5
GROUPADMINPERMISSION_EDITMESSAGE = 6
GROUPADMINPERMISSION_DELETEMESSAGE = 7
GROUPADMINPERMISSION_GETINTEGRATIONTOKEN = 8
GROUPADMINPERMISSION_SENDMESSAGE = 9
GROUPADMINPERMISSION_PINMESSAGE = 10
GROUPADMINPERMISSION_VIEWMEMBERS = 11
GROUPADMINPERMISSION_LEAVE = 12
GROUPADMINPERMISSION_TARGETING = 13
GROUPADMINPERMISSION_DELETE = 14
GROUPADMINPERMISSION_MANAGE_CONFERENCE = 15



_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='dialog.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.Member.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invited_at', full_name='dialog.Member.invited_at', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.Member.permissions', index=2,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.Member.clock', index=3,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.Member.deleted_at', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=490,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='dialog.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Group.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.Group.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.Group.data', index=2,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_member', full_name='dialog.Group.self_member', index=3,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.Group.title', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.Group.group_type', index=5,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.Group.shortname', index=6,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=851,
)


_GROUPDATA = _descriptor.Descriptor(
  name='GroupData',
  full_name='dialog.GroupData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.GroupData.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.GroupData.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.GroupData.avatar', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members_amount', full_name='dialog.GroupData.members_amount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.GroupData.group_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='dialog.GroupData.owner_user_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='dialog.GroupData.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.GroupData.about', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.GroupData.shortname', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_permissions', full_name='dialog.GroupData.base_permissions', index=9,
      number=10, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.GroupData.clock', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pinned_at', full_name='dialog.GroupData.pinned_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conference_link', full_name='dialog.GroupData.conference_link', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members_count_limit', full_name='dialog.GroupData.members_count_limit', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.GroupData.deleted_at', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=1606,
)


_GROUPPARTIALINFO = _descriptor.Descriptor(
  name='GroupPartialInfo',
  full_name='dialog.GroupPartialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.GroupPartialInfo.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.GroupPartialInfo.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.GroupPartialInfo.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.GroupPartialInfo.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.GroupPartialInfo.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.GroupPartialInfo.shortname', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.GroupPartialInfo.avatar', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_member', full_name='dialog.GroupPartialInfo.self_member', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pinned_at', full_name='dialog.GroupPartialInfo.pinned_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1609,
  serialized_end=1993,
)


_UPDATEGROUP = _descriptor.Descriptor(
  name='UpdateGroup',
  full_name='dialog.UpdateGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateGroup.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.UpdateGroup.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1995,
  serialized_end=2053,
)


_REQUESTLOADMEMBERS = _descriptor.Descriptor(
  name='RequestLoadMembers',
  full_name='dialog.RequestLoadMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.RequestLoadMembers.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadMembers.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next', full_name='dialog.RequestLoadMembers.next', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2056,
  serialized_end=2246,
)


_RESPONSELOADMEMBERS = _descriptor.Descriptor(
  name='ResponseLoadMembers',
  full_name='dialog.ResponseLoadMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cursor', full_name='dialog.ResponseLoadMembers.cursor', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.ResponseLoadMembers.members', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2409,
)


_UPDATEGROUPTITLECHANGED = _descriptor.Descriptor(
  name='UpdateGroupTitleChanged',
  full_name='dialog.UpdateGroupTitleChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTitleChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.UpdateGroupTitleChanged.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2498,
)


_UPDATEGROUPAVATARCHANGED = _descriptor.Descriptor(
  name='UpdateGroupAvatarChanged',
  full_name='dialog.UpdateGroupAvatarChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAvatarChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UpdateGroupAvatarChanged.avatar', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2500,
  serialized_end=2606,
)


_UPDATEGROUPABOUTCHANGED = _descriptor.Descriptor(
  name='UpdateGroupAboutChanged',
  full_name='dialog.UpdateGroupAboutChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAboutChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UpdateGroupAboutChanged.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2608,
  serialized_end=2725,
)


_UPDATEGROUPOWNERCHANGED = _descriptor.Descriptor(
  name='UpdateGroupOwnerChanged',
  full_name='dialog.UpdateGroupOwnerChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupOwnerChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateGroupOwnerChanged.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2817,
)


_UPDATEGROUPBASEPERMISSIONSCHANGED = _descriptor.Descriptor(
  name='UpdateGroupBasePermissionsChanged',
  full_name='dialog.UpdateGroupBasePermissionsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupBasePermissionsChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_permissions', full_name='dialog.UpdateGroupBasePermissionsChanged.base_permissions', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2820,
  serialized_end=2959,
)


_UPDATEGROUPMEMBERSUPDATED = _descriptor.Descriptor(
  name='UpdateGroupMembersUpdated',
  full_name='dialog.UpdateGroupMembersUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersUpdated.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.UpdateGroupMembersUpdated.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2961,
  serialized_end=3069,
)


_UPDATEGROUPMEMBERDIFF = _descriptor.Descriptor(
  name='UpdateGroupMemberDiff',
  full_name='dialog.UpdateGroupMemberDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='removed_users', full_name='dialog.UpdateGroupMemberDiff.removed_users', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added_members', full_name='dialog.UpdateGroupMemberDiff.added_members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members_count', full_name='dialog.UpdateGroupMemberDiff.members_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3072,
  serialized_end=3225,
)


_UPDATEGROUPMEMBERSCOUNTCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMembersCountChanged',
  full_name='dialog.UpdateGroupMembersCountChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersCountChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members_count', full_name='dialog.UpdateGroupMembersCountChanged.members_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3227,
  serialized_end=3330,
)


_REQUESTCREATEGROUP = _descriptor.Descriptor(
  name='RequestCreateGroup',
  full_name='dialog.RequestCreateGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestCreateGroup.rid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.RequestCreateGroup.space_id', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestCreateGroup.title', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestCreateGroup.users', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.RequestCreateGroup.group_type', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='dialog.RequestCreateGroup.username', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestCreateGroup.optimizations', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_permissions', full_name='dialog.RequestCreateGroup.base_permissions', index=7,
      number=10, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3333,
  serialized_end=3782,
)


_RESPONSECREATEGROUP = _descriptor.Descriptor(
  name='ResponseCreateGroup',
  full_name='dialog.ResponseCreateGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseCreateGroup.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseCreateGroup.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.ResponseCreateGroup.group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseCreateGroup.user_peers', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3785,
  serialized_end=3942,
)


_REQUESTEDITGROUPTITLE = _descriptor.Descriptor(
  name='RequestEditGroupTitle',
  full_name='dialog.RequestEditGroupTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupTitle.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupTitle.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestEditGroupTitle.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupTitle.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3945,
  serialized_end=4178,
)


_REQUESTSETGROUPSHORTNAME = _descriptor.Descriptor(
  name='RequestSetGroupShortname',
  full_name='dialog.RequestSetGroupShortname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestSetGroupShortname.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestSetGroupShortname.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4181,
  serialized_end=4322,
)


_REQUESTEDITGROUPAVATAR = _descriptor.Descriptor(
  name='RequestEditGroupAvatar',
  full_name='dialog.RequestEditGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupAvatar.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupAvatar.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.RequestEditGroupAvatar.file_location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupAvatar.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4325,
  serialized_end=4590,
)


_RESPONSEEDITGROUPAVATAR = _descriptor.Descriptor(
  name='ResponseEditGroupAvatar',
  full_name='dialog.ResponseEditGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.ResponseEditGroupAvatar.avatar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseEditGroupAvatar.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseEditGroupAvatar.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseEditGroupAvatar.date', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseEditGroupAvatar.mid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4593,
  serialized_end=4755,
)


_REQUESTREMOVEGROUPAVATAR = _descriptor.Descriptor(
  name='RequestRemoveGroupAvatar',
  full_name='dialog.RequestRemoveGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestRemoveGroupAvatar.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestRemoveGroupAvatar.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestRemoveGroupAvatar.optimizations', index=2,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4758,
  serialized_end=4965,
)


_REQUESTEDITGROUPABOUT = _descriptor.Descriptor(
  name='RequestEditGroupAbout',
  full_name='dialog.RequestEditGroupAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupAbout.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupAbout.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestEditGroupAbout.about', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupAbout.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4968,
  serialized_end=5231,
)


_REQUESTEDITGROUPBASEPERMISSIONS = _descriptor.Descriptor(
  name='RequestEditGroupBasePermissions',
  full_name='dialog.RequestEditGroupBasePermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupBasePermissions.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_id', full_name='dialog.RequestEditGroupBasePermissions.random_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granted_permissions', full_name='dialog.RequestEditGroupBasePermissions.granted_permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoked_permissions', full_name='dialog.RequestEditGroupBasePermissions.revoked_permissions', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5234,
  serialized_end=5536,
)


_REQUESTEDITMEMBERPERMISSIONS = _descriptor.Descriptor(
  name='RequestEditMemberPermissions',
  full_name='dialog.RequestEditMemberPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditMemberPermissions.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peer', full_name='dialog.RequestEditMemberPermissions.user_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granted_permissions', full_name='dialog.RequestEditMemberPermissions.granted_permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoked_permissions', full_name='dialog.RequestEditMemberPermissions.revoked_permissions', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5539,
  serialized_end=5859,
)


_RESPONSEMEMBER = _descriptor.Descriptor(
  name='ResponseMember',
  full_name='dialog.ResponseMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.ResponseMember.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5861,
  serialized_end=5940,
)


_REQUESTINVITEUSER = _descriptor.Descriptor(
  name='RequestInviteUser',
  full_name='dialog.RequestInviteUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestInviteUser.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestInviteUser.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.RequestInviteUser.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestInviteUser.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5943,
  serialized_end=6193,
)


_REQUESTLEAVEGROUP = _descriptor.Descriptor(
  name='RequestLeaveGroup',
  full_name='dialog.RequestLeaveGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestLeaveGroup.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestLeaveGroup.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLeaveGroup.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6196,
  serialized_end=6396,
)


_REQUESTKICKUSER = _descriptor.Descriptor(
  name='RequestKickUser',
  full_name='dialog.RequestKickUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestKickUser.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestKickUser.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.RequestKickUser.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestKickUser.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6399,
  serialized_end=6647,
)


_REQUESTMAKEUSERADMIN = _descriptor.Descriptor(
  name='RequestMakeUserAdmin',
  full_name='dialog.RequestMakeUserAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestMakeUserAdmin.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peer', full_name='dialog.RequestMakeUserAdmin.user_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.RequestMakeUserAdmin.permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6650,
  serialized_end=6880,
)


_GROUPMEMBERPERMISSION = _descriptor.Descriptor(
  name='GroupMemberPermission',
  full_name='dialog.GroupMemberPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.GroupMemberPermission.user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.GroupMemberPermission.permissions', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6882,
  serialized_end=7002,
)


_REQUESTGETGROUPMEMBERPERMISSIONS = _descriptor.Descriptor(
  name='RequestGetGroupMemberPermissions',
  full_name='dialog.RequestGetGroupMemberPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.RequestGetGroupMemberPermissions.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='dialog.RequestGetGroupMemberPermissions.user_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7005,
  serialized_end=7135,
)


_RESPONSEGETGROUPMEMBERPERMISSIONS = _descriptor.Descriptor(
  name='ResponseGetGroupMemberPermissions',
  full_name='dialog.ResponseGetGroupMemberPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.ResponseGetGroupMemberPermissions.permissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7137,
  serialized_end=7255,
)


_UPDATEGROUPMEMBERPERMISSIONSCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMemberPermissionsChanged',
  full_name='dialog.UpdateGroupMemberPermissionsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMemberPermissionsChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateGroupMemberPermissionsChanged.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.UpdateGroupMemberPermissionsChanged.permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7258,
  serialized_end=7426,
)


_REQUESTTRANSFEROWNERSHIP = _descriptor.Descriptor(
  name='RequestTransferOwnership',
  full_name='dialog.RequestTransferOwnership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestTransferOwnership.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_owner', full_name='dialog.RequestTransferOwnership.new_owner', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7429,
  serialized_end=7576,
)


_RESPONSEINVITEURL = _descriptor.Descriptor(
  name='ResponseInviteUrl',
  full_name='dialog.ResponseInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseInviteUrl.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7578,
  serialized_end=7641,
)


_REQUESTGETGROUPINVITEURL = _descriptor.Descriptor(
  name='RequestGetGroupInviteUrl',
  full_name='dialog.RequestGetGroupInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestGetGroupInviteUrl.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7643,
  serialized_end=7756,
)


_REQUESTGETGROUPINVITEURLBASE = _descriptor.Descriptor(
  name='RequestGetGroupInviteUrlBase',
  full_name='dialog.RequestGetGroupInviteUrlBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7758,
  serialized_end=7818,
)


_RESPONSEGETGROUPINVITEURLBASE = _descriptor.Descriptor(
  name='ResponseGetGroupInviteUrlBase',
  full_name='dialog.ResponseGetGroupInviteUrlBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseGetGroupInviteUrlBase.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7820,
  serialized_end=7895,
)


_REQUESTREVOKEINVITEURL = _descriptor.Descriptor(
  name='RequestRevokeInviteUrl',
  full_name='dialog.RequestRevokeInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestRevokeInviteUrl.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7897,
  serialized_end=8008,
)


_REQUESTJOINGROUP = _descriptor.Descriptor(
  name='RequestJoinGroup',
  full_name='dialog.RequestJoinGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestJoinGroup.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestJoinGroup.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8011,
  serialized_end=8154,
)


_RESPONSEJOINGROUP = _descriptor.Descriptor(
  name='ResponseJoinGroup',
  full_name='dialog.ResponseJoinGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.ResponseJoinGroup.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseJoinGroup.user_peers', index=1,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseJoinGroup.mid', index=2,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseJoinGroup.seq', index=3,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseJoinGroup.state', index=4,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseJoinGroup.date', index=5,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8157,
  serialized_end=8358,
)


_REQUESTJOINGROUPBYPEER = _descriptor.Descriptor(
  name='RequestJoinGroupByPeer',
  full_name='dialog.RequestJoinGroupByPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestJoinGroupByPeer.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8360,
  serialized_end=8465,
)


_REQUESTDELETEGROUP = _descriptor.Descriptor(
  name='RequestDeleteGroup',
  full_name='dialog.RequestDeleteGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.RequestDeleteGroup.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8467,
  serialized_end=8550,
)


_REQUESTGETGROUPPARTIALINFO = _descriptor.Descriptor(
  name='RequestGetGroupPartialInfo',
  full_name='dialog.RequestGetGroupPartialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestGetGroupPartialInfo.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8552,
  serialized_end=8640,
)


_UPDATEGROUPMEMBERINVITED = _descriptor.Descriptor(
  name='UpdateGroupMemberInvited',
  full_name='dialog.UpdateGroupMemberInvited',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMemberInvited.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.UpdateGroupMemberInvited.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8642,
  serialized_end=8733,
)


_UPDATEGROUPINVITEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupInviteObsolete',
  full_name='dialog.UpdateGroupInviteObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupInviteObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateGroupInviteObsolete.rid', index=1,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupInviteObsolete.mid', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_uid', full_name='dialog.UpdateGroupInviteObsolete.invite_uid', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupInviteObsolete.date', index=4,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8736,
  serialized_end=8920,
)


_UPDATEGROUPUSERINVITEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserInvitedObsolete',
  full_name='dialog.UpdateGroupUserInvitedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserInvitedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateGroupUserInvitedObsolete.rid', index=1,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserInvitedObsolete.mid', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserInvitedObsolete.uid', index=3,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inviter_uid', full_name='dialog.UpdateGroupUserInvitedObsolete.inviter_uid', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserInvitedObsolete.date', index=5,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8923,
  serialized_end=9156,
)


_UPDATEGROUPUSERLEAVEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserLeaveObsolete',
  full_name='dialog.UpdateGroupUserLeaveObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserLeaveObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserLeaveObsolete.mid', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserLeaveObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserLeaveObsolete.date', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9159,
  serialized_end=9311,
)


_UPDATEGROUPUSERKICKOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserKickObsolete',
  full_name='dialog.UpdateGroupUserKickObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserKickObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserKickObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserKickObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kicker_uid', full_name='dialog.UpdateGroupUserKickObsolete.kicker_uid', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserKickObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9314,
  serialized_end=9500,
)


_UPDATEGROUPMEMBERSUPDATEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupMembersUpdateObsolete',
  full_name='dialog.UpdateGroupMembersUpdateObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersUpdateObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.UpdateGroupMembersUpdateObsolete.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9502,
  serialized_end=9617,
)


_UPDATEGROUPTITLECHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupTitleChangedObsolete',
  full_name='dialog.UpdateGroupTitleChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTitleChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupTitleChangedObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupTitleChangedObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.UpdateGroupTitleChangedObsolete.title', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupTitleChangedObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9620,
  serialized_end=9804,
)


_UPDATEGROUPABOUTCHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupAboutChangedObsolete',
  full_name='dialog.UpdateGroupAboutChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAboutChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UpdateGroupAboutChangedObsolete.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9806,
  serialized_end=9931,
)


_UPDATEGROUPAVATARCHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupAvatarChangedObsolete',
  full_name='dialog.UpdateGroupAvatarChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAvatarChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupAvatarChangedObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupAvatarChangedObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UpdateGroupAvatarChangedObsolete.avatar', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupAvatarChangedObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9934,
  serialized_end=10137,
)


_UPDATEGROUPSHORTNAMECHANGED = _descriptor.Descriptor(
  name='UpdateGroupShortnameChanged',
  full_name='dialog.UpdateGroupShortnameChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupShortnameChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.UpdateGroupShortnameChanged.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupShortnameChanged.uid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10139,
  serialized_end=10263,
)

_MEMBER.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_MEMBER.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUP.fields_by_name['data'].message_type = _GROUPDATA
_GROUP.fields_by_name['self_member'].message_type = _MEMBER
_GROUP.fields_by_name['group_type'].enum_type = _GROUPTYPE
_GROUP.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPDATA.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_GROUPDATA.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_GROUPDATA.fields_by_name['group_type'].enum_type = _GROUPTYPE
_GROUPDATA.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUPDATA.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPDATA.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPDATA.fields_by_name['base_permissions'].enum_type = _GROUPADMINPERMISSION
_GROUPDATA.fields_by_name['pinned_at'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GROUPDATA.fields_by_name['conference_link'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPDATA.fields_by_name['members_count_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GROUPDATA.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GROUPPARTIALINFO.fields_by_name['type'].enum_type = _GROUPTYPE
_GROUPPARTIALINFO.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPPARTIALINFO.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_GROUPPARTIALINFO.fields_by_name['self_member'].message_type = _MEMBER
_GROUPPARTIALINFO.fields_by_name['pinned_at'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_UPDATEGROUP.fields_by_name['data'].message_type = _GROUPDATA
_REQUESTLOADMEMBERS.fields_by_name['group'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLOADMEMBERS.fields_by_name['next'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSELOADMEMBERS.fields_by_name['cursor'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSELOADMEMBERS.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPAVATARCHANGED.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_UPDATEGROUPABOUTCHANGED.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPBASEPERMISSIONSCHANGED.fields_by_name['base_permissions'].enum_type = _GROUPADMINPERMISSION
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPMEMBERDIFF.fields_by_name['added_members'].message_type = _MEMBER
_REQUESTCREATEGROUP.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTCREATEGROUP.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTCREATEGROUP.fields_by_name['group_type'].enum_type = _GROUPTYPE
_REQUESTCREATEGROUP.fields_by_name['username'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATEGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTCREATEGROUP.fields_by_name['base_permissions'].enum_type = _GROUPADMINPERMISSION
_RESPONSECREATEGROUP.fields_by_name['group'].message_type = _GROUP
_RESPONSECREATEGROUP.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTEDITGROUPTITLE.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPTITLE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTSETGROUPSHORTNAME.fields_by_name['peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPAVATAR.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPAVATAR.fields_by_name['file_location'].message_type = media__and__files__pb2._FILELOCATION
_REQUESTEDITGROUPAVATAR.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEEDITGROUPAVATAR.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_RESPONSEEDITGROUPAVATAR.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREMOVEGROUPAVATAR.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTREMOVEGROUPAVATAR.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTEDITGROUPABOUT.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTEDITGROUPABOUT.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['granted_permissions'].enum_type = _GROUPADMINPERMISSION
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['revoked_permissions'].enum_type = _GROUPADMINPERMISSION
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['user_peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['granted_permissions'].enum_type = _GROUPADMINPERMISSION
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['revoked_permissions'].enum_type = _GROUPADMINPERMISSION
_RESPONSEMEMBER.fields_by_name['member'].message_type = _MEMBER
_REQUESTINVITEUSER.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTINVITEUSER.fields_by_name['user'].message_type = peers__pb2._USEROUTPEER
_REQUESTINVITEUSER.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTLEAVEGROUP.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLEAVEGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTKICKUSER.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTKICKUSER.fields_by_name['user'].message_type = peers__pb2._USEROUTPEER
_REQUESTKICKUSER.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTMAKEUSERADMIN.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTMAKEUSERADMIN.fields_by_name['user_peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTMAKEUSERADMIN.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_GROUPMEMBERPERMISSION.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_RESPONSEGETGROUPMEMBERPERMISSIONS.fields_by_name['permissions'].message_type = _GROUPMEMBERPERMISSION
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_REQUESTTRANSFEROWNERSHIP.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTGETGROUPINVITEURL.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTREVOKEINVITEURL.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTJOINGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEJOINGROUP.fields_by_name['group'].message_type = _GROUP
_RESPONSEJOINGROUP.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSEJOINGROUP.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTJOINGROUPBYPEER.fields_by_name['peer'].message_type = peers__pb2._GROUPOUTPEER
_UPDATEGROUPMEMBERINVITED.fields_by_name['member'].message_type = _MEMBER
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['GroupData'] = _GROUPDATA
DESCRIPTOR.message_types_by_name['GroupPartialInfo'] = _GROUPPARTIALINFO
DESCRIPTOR.message_types_by_name['UpdateGroup'] = _UPDATEGROUP
DESCRIPTOR.message_types_by_name['RequestLoadMembers'] = _REQUESTLOADMEMBERS
DESCRIPTOR.message_types_by_name['ResponseLoadMembers'] = _RESPONSELOADMEMBERS
DESCRIPTOR.message_types_by_name['UpdateGroupTitleChanged'] = _UPDATEGROUPTITLECHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupAvatarChanged'] = _UPDATEGROUPAVATARCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupAboutChanged'] = _UPDATEGROUPABOUTCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupOwnerChanged'] = _UPDATEGROUPOWNERCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupBasePermissionsChanged'] = _UPDATEGROUPBASEPERMISSIONSCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupMembersUpdated'] = _UPDATEGROUPMEMBERSUPDATED
DESCRIPTOR.message_types_by_name['UpdateGroupMemberDiff'] = _UPDATEGROUPMEMBERDIFF
DESCRIPTOR.message_types_by_name['UpdateGroupMembersCountChanged'] = _UPDATEGROUPMEMBERSCOUNTCHANGED
DESCRIPTOR.message_types_by_name['RequestCreateGroup'] = _REQUESTCREATEGROUP
DESCRIPTOR.message_types_by_name['ResponseCreateGroup'] = _RESPONSECREATEGROUP
DESCRIPTOR.message_types_by_name['RequestEditGroupTitle'] = _REQUESTEDITGROUPTITLE
DESCRIPTOR.message_types_by_name['RequestSetGroupShortname'] = _REQUESTSETGROUPSHORTNAME
DESCRIPTOR.message_types_by_name['RequestEditGroupAvatar'] = _REQUESTEDITGROUPAVATAR
DESCRIPTOR.message_types_by_name['ResponseEditGroupAvatar'] = _RESPONSEEDITGROUPAVATAR
DESCRIPTOR.message_types_by_name['RequestRemoveGroupAvatar'] = _REQUESTREMOVEGROUPAVATAR
DESCRIPTOR.message_types_by_name['RequestEditGroupAbout'] = _REQUESTEDITGROUPABOUT
DESCRIPTOR.message_types_by_name['RequestEditGroupBasePermissions'] = _REQUESTEDITGROUPBASEPERMISSIONS
DESCRIPTOR.message_types_by_name['RequestEditMemberPermissions'] = _REQUESTEDITMEMBERPERMISSIONS
DESCRIPTOR.message_types_by_name['ResponseMember'] = _RESPONSEMEMBER
DESCRIPTOR.message_types_by_name['RequestInviteUser'] = _REQUESTINVITEUSER
DESCRIPTOR.message_types_by_name['RequestLeaveGroup'] = _REQUESTLEAVEGROUP
DESCRIPTOR.message_types_by_name['RequestKickUser'] = _REQUESTKICKUSER
DESCRIPTOR.message_types_by_name['RequestMakeUserAdmin'] = _REQUESTMAKEUSERADMIN
DESCRIPTOR.message_types_by_name['GroupMemberPermission'] = _GROUPMEMBERPERMISSION
DESCRIPTOR.message_types_by_name['RequestGetGroupMemberPermissions'] = _REQUESTGETGROUPMEMBERPERMISSIONS
DESCRIPTOR.message_types_by_name['ResponseGetGroupMemberPermissions'] = _RESPONSEGETGROUPMEMBERPERMISSIONS
DESCRIPTOR.message_types_by_name['UpdateGroupMemberPermissionsChanged'] = _UPDATEGROUPMEMBERPERMISSIONSCHANGED
DESCRIPTOR.message_types_by_name['RequestTransferOwnership'] = _REQUESTTRANSFEROWNERSHIP
DESCRIPTOR.message_types_by_name['ResponseInviteUrl'] = _RESPONSEINVITEURL
DESCRIPTOR.message_types_by_name['RequestGetGroupInviteUrl'] = _REQUESTGETGROUPINVITEURL
DESCRIPTOR.message_types_by_name['RequestGetGroupInviteUrlBase'] = _REQUESTGETGROUPINVITEURLBASE
DESCRIPTOR.message_types_by_name['ResponseGetGroupInviteUrlBase'] = _RESPONSEGETGROUPINVITEURLBASE
DESCRIPTOR.message_types_by_name['RequestRevokeInviteUrl'] = _REQUESTREVOKEINVITEURL
DESCRIPTOR.message_types_by_name['RequestJoinGroup'] = _REQUESTJOINGROUP
DESCRIPTOR.message_types_by_name['ResponseJoinGroup'] = _RESPONSEJOINGROUP
DESCRIPTOR.message_types_by_name['RequestJoinGroupByPeer'] = _REQUESTJOINGROUPBYPEER
DESCRIPTOR.message_types_by_name['RequestDeleteGroup'] = _REQUESTDELETEGROUP
DESCRIPTOR.message_types_by_name['RequestGetGroupPartialInfo'] = _REQUESTGETGROUPPARTIALINFO
DESCRIPTOR.message_types_by_name['UpdateGroupMemberInvited'] = _UPDATEGROUPMEMBERINVITED
DESCRIPTOR.message_types_by_name['UpdateGroupInviteObsolete'] = _UPDATEGROUPINVITEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserInvitedObsolete'] = _UPDATEGROUPUSERINVITEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserLeaveObsolete'] = _UPDATEGROUPUSERLEAVEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserKickObsolete'] = _UPDATEGROUPUSERKICKOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupMembersUpdateObsolete'] = _UPDATEGROUPMEMBERSUPDATEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupTitleChangedObsolete'] = _UPDATEGROUPTITLECHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupAboutChangedObsolete'] = _UPDATEGROUPABOUTCHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupAvatarChangedObsolete'] = _UPDATEGROUPAVATARCHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupShortnameChanged'] = _UPDATEGROUPSHORTNAMECHANGED
DESCRIPTOR.enum_types_by_name['GroupType'] = _GROUPTYPE
DESCRIPTOR.enum_types_by_name['GroupAdminPermission'] = _GROUPADMINPERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Member)
  })
_sym_db.RegisterMessage(Member)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
  'DESCRIPTOR' : _GROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Group)
  })
_sym_db.RegisterMessage(Group)

GroupData = _reflection.GeneratedProtocolMessageType('GroupData', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDATA,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupData)
  })
_sym_db.RegisterMessage(GroupData)

GroupPartialInfo = _reflection.GeneratedProtocolMessageType('GroupPartialInfo', (_message.Message,), {
  'DESCRIPTOR' : _GROUPPARTIALINFO,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupPartialInfo)
  })
_sym_db.RegisterMessage(GroupPartialInfo)

UpdateGroup = _reflection.GeneratedProtocolMessageType('UpdateGroup', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroup)
  })
_sym_db.RegisterMessage(UpdateGroup)

RequestLoadMembers = _reflection.GeneratedProtocolMessageType('RequestLoadMembers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADMEMBERS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadMembers)
  })
_sym_db.RegisterMessage(RequestLoadMembers)

ResponseLoadMembers = _reflection.GeneratedProtocolMessageType('ResponseLoadMembers', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADMEMBERS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadMembers)
  })
_sym_db.RegisterMessage(ResponseLoadMembers)

UpdateGroupTitleChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupTitleChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPTITLECHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTitleChanged)
  })
_sym_db.RegisterMessage(UpdateGroupTitleChanged)

UpdateGroupAvatarChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupAvatarChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPAVATARCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAvatarChanged)
  })
_sym_db.RegisterMessage(UpdateGroupAvatarChanged)

UpdateGroupAboutChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupAboutChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPABOUTCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAboutChanged)
  })
_sym_db.RegisterMessage(UpdateGroupAboutChanged)

UpdateGroupOwnerChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupOwnerChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPOWNERCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupOwnerChanged)
  })
_sym_db.RegisterMessage(UpdateGroupOwnerChanged)

UpdateGroupBasePermissionsChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupBasePermissionsChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPBASEPERMISSIONSCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupBasePermissionsChanged)
  })
_sym_db.RegisterMessage(UpdateGroupBasePermissionsChanged)

UpdateGroupMembersUpdated = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersUpdated', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERSUPDATED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersUpdated)
  })
_sym_db.RegisterMessage(UpdateGroupMembersUpdated)

UpdateGroupMemberDiff = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberDiff', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERDIFF,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberDiff)
  })
_sym_db.RegisterMessage(UpdateGroupMemberDiff)

UpdateGroupMembersCountChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersCountChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERSCOUNTCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersCountChanged)
  })
_sym_db.RegisterMessage(UpdateGroupMembersCountChanged)

RequestCreateGroup = _reflection.GeneratedProtocolMessageType('RequestCreateGroup', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCREATEGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCreateGroup)
  })
_sym_db.RegisterMessage(RequestCreateGroup)

ResponseCreateGroup = _reflection.GeneratedProtocolMessageType('ResponseCreateGroup', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSECREATEGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseCreateGroup)
  })
_sym_db.RegisterMessage(ResponseCreateGroup)

RequestEditGroupTitle = _reflection.GeneratedProtocolMessageType('RequestEditGroupTitle', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITGROUPTITLE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupTitle)
  })
_sym_db.RegisterMessage(RequestEditGroupTitle)

RequestSetGroupShortname = _reflection.GeneratedProtocolMessageType('RequestSetGroupShortname', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETGROUPSHORTNAME,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetGroupShortname)
  })
_sym_db.RegisterMessage(RequestSetGroupShortname)

RequestEditGroupAvatar = _reflection.GeneratedProtocolMessageType('RequestEditGroupAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITGROUPAVATAR,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupAvatar)
  })
_sym_db.RegisterMessage(RequestEditGroupAvatar)

ResponseEditGroupAvatar = _reflection.GeneratedProtocolMessageType('ResponseEditGroupAvatar', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEEDITGROUPAVATAR,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseEditGroupAvatar)
  })
_sym_db.RegisterMessage(ResponseEditGroupAvatar)

RequestRemoveGroupAvatar = _reflection.GeneratedProtocolMessageType('RequestRemoveGroupAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREMOVEGROUPAVATAR,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveGroupAvatar)
  })
_sym_db.RegisterMessage(RequestRemoveGroupAvatar)

RequestEditGroupAbout = _reflection.GeneratedProtocolMessageType('RequestEditGroupAbout', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITGROUPABOUT,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupAbout)
  })
_sym_db.RegisterMessage(RequestEditGroupAbout)

RequestEditGroupBasePermissions = _reflection.GeneratedProtocolMessageType('RequestEditGroupBasePermissions', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITGROUPBASEPERMISSIONS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupBasePermissions)
  })
_sym_db.RegisterMessage(RequestEditGroupBasePermissions)

RequestEditMemberPermissions = _reflection.GeneratedProtocolMessageType('RequestEditMemberPermissions', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITMEMBERPERMISSIONS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditMemberPermissions)
  })
_sym_db.RegisterMessage(RequestEditMemberPermissions)

ResponseMember = _reflection.GeneratedProtocolMessageType('ResponseMember', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEMEMBER,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseMember)
  })
_sym_db.RegisterMessage(ResponseMember)

RequestInviteUser = _reflection.GeneratedProtocolMessageType('RequestInviteUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINVITEUSER,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestInviteUser)
  })
_sym_db.RegisterMessage(RequestInviteUser)

RequestLeaveGroup = _reflection.GeneratedProtocolMessageType('RequestLeaveGroup', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLEAVEGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLeaveGroup)
  })
_sym_db.RegisterMessage(RequestLeaveGroup)

RequestKickUser = _reflection.GeneratedProtocolMessageType('RequestKickUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTKICKUSER,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestKickUser)
  })
_sym_db.RegisterMessage(RequestKickUser)

RequestMakeUserAdmin = _reflection.GeneratedProtocolMessageType('RequestMakeUserAdmin', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTMAKEUSERADMIN,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMakeUserAdmin)
  })
_sym_db.RegisterMessage(RequestMakeUserAdmin)

GroupMemberPermission = _reflection.GeneratedProtocolMessageType('GroupMemberPermission', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMEMBERPERMISSION,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupMemberPermission)
  })
_sym_db.RegisterMessage(GroupMemberPermission)

RequestGetGroupMemberPermissions = _reflection.GeneratedProtocolMessageType('RequestGetGroupMemberPermissions', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETGROUPMEMBERPERMISSIONS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupMemberPermissions)
  })
_sym_db.RegisterMessage(RequestGetGroupMemberPermissions)

ResponseGetGroupMemberPermissions = _reflection.GeneratedProtocolMessageType('ResponseGetGroupMemberPermissions', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETGROUPMEMBERPERMISSIONS,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetGroupMemberPermissions)
  })
_sym_db.RegisterMessage(ResponseGetGroupMemberPermissions)

UpdateGroupMemberPermissionsChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberPermissionsChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERPERMISSIONSCHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberPermissionsChanged)
  })
_sym_db.RegisterMessage(UpdateGroupMemberPermissionsChanged)

RequestTransferOwnership = _reflection.GeneratedProtocolMessageType('RequestTransferOwnership', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTRANSFEROWNERSHIP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestTransferOwnership)
  })
_sym_db.RegisterMessage(RequestTransferOwnership)

ResponseInviteUrl = _reflection.GeneratedProtocolMessageType('ResponseInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINVITEURL,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseInviteUrl)
  })
_sym_db.RegisterMessage(ResponseInviteUrl)

RequestGetGroupInviteUrl = _reflection.GeneratedProtocolMessageType('RequestGetGroupInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETGROUPINVITEURL,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupInviteUrl)
  })
_sym_db.RegisterMessage(RequestGetGroupInviteUrl)

RequestGetGroupInviteUrlBase = _reflection.GeneratedProtocolMessageType('RequestGetGroupInviteUrlBase', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETGROUPINVITEURLBASE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupInviteUrlBase)
  })
_sym_db.RegisterMessage(RequestGetGroupInviteUrlBase)

ResponseGetGroupInviteUrlBase = _reflection.GeneratedProtocolMessageType('ResponseGetGroupInviteUrlBase', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETGROUPINVITEURLBASE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetGroupInviteUrlBase)
  })
_sym_db.RegisterMessage(ResponseGetGroupInviteUrlBase)

RequestRevokeInviteUrl = _reflection.GeneratedProtocolMessageType('RequestRevokeInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREVOKEINVITEURL,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRevokeInviteUrl)
  })
_sym_db.RegisterMessage(RequestRevokeInviteUrl)

RequestJoinGroup = _reflection.GeneratedProtocolMessageType('RequestJoinGroup', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTJOINGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinGroup)
  })
_sym_db.RegisterMessage(RequestJoinGroup)

ResponseJoinGroup = _reflection.GeneratedProtocolMessageType('ResponseJoinGroup', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEJOINGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseJoinGroup)
  })
_sym_db.RegisterMessage(ResponseJoinGroup)

RequestJoinGroupByPeer = _reflection.GeneratedProtocolMessageType('RequestJoinGroupByPeer', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTJOINGROUPBYPEER,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinGroupByPeer)
  })
_sym_db.RegisterMessage(RequestJoinGroupByPeer)

RequestDeleteGroup = _reflection.GeneratedProtocolMessageType('RequestDeleteGroup', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELETEGROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteGroup)
  })
_sym_db.RegisterMessage(RequestDeleteGroup)

RequestGetGroupPartialInfo = _reflection.GeneratedProtocolMessageType('RequestGetGroupPartialInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETGROUPPARTIALINFO,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupPartialInfo)
  })
_sym_db.RegisterMessage(RequestGetGroupPartialInfo)

UpdateGroupMemberInvited = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberInvited', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERINVITED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberInvited)
  })
_sym_db.RegisterMessage(UpdateGroupMemberInvited)

UpdateGroupInviteObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupInviteObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPINVITEOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupInviteObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupInviteObsolete)

UpdateGroupUserInvitedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserInvitedObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPUSERINVITEDOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserInvitedObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupUserInvitedObsolete)

UpdateGroupUserLeaveObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserLeaveObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPUSERLEAVEOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserLeaveObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupUserLeaveObsolete)

UpdateGroupUserKickObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserKickObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPUSERKICKOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserKickObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupUserKickObsolete)

UpdateGroupMembersUpdateObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersUpdateObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERSUPDATEOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersUpdateObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupMembersUpdateObsolete)

UpdateGroupTitleChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupTitleChangedObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPTITLECHANGEDOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTitleChangedObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupTitleChangedObsolete)

UpdateGroupAboutChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupAboutChangedObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPABOUTCHANGEDOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAboutChangedObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupAboutChangedObsolete)

UpdateGroupAvatarChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupAvatarChangedObsolete', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPAVATARCHANGEDOBSOLETE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAvatarChangedObsolete)
  })
_sym_db.RegisterMessage(UpdateGroupAvatarChangedObsolete)

UpdateGroupShortnameChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupShortnameChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPSHORTNAMECHANGED,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupShortnameChanged)
  })
_sym_db.RegisterMessage(UpdateGroupShortnameChanged)


DESCRIPTOR._options = None
_MEMBER.fields_by_name['uid']._options = None
_MEMBER.fields_by_name['invited_at']._options = None
_MEMBER.fields_by_name['permissions']._options = None
_MEMBER.fields_by_name['clock']._options = None
_MEMBER.fields_by_name['deleted_at']._options = None
_GROUP.fields_by_name['id']._options = None
_GROUP.fields_by_name['access_hash']._options = None
_GROUP.fields_by_name['title']._options = None
_GROUP.fields_by_name['group_type']._options = None
_GROUP.fields_by_name['shortname']._options = None
_GROUPDATA.fields_by_name['title']._options = None
_GROUPDATA.fields_by_name['avatar']._options = None
_GROUPDATA.fields_by_name['members_amount']._options = None
_GROUPDATA.fields_by_name['group_type']._options = None
_GROUPDATA.fields_by_name['owner_user_id']._options = None
_GROUPDATA.fields_by_name['created_at']._options = None
_GROUPDATA.fields_by_name['about']._options = None
_GROUPDATA.fields_by_name['shortname']._options = None
_GROUPDATA.fields_by_name['base_permissions']._options = None
_GROUPDATA.fields_by_name['clock']._options = None
_GROUPPARTIALINFO.fields_by_name['id']._options = None
_GROUPPARTIALINFO.fields_by_name['access_hash']._options = None
_GROUPPARTIALINFO.fields_by_name['clock']._options = None
_GROUPPARTIALINFO.fields_by_name['type']._options = None
_GROUPPARTIALINFO.fields_by_name['title']._options = None
_GROUPPARTIALINFO.fields_by_name['shortname']._options = None
_GROUPPARTIALINFO.fields_by_name['avatar']._options = None
_REQUESTLOADMEMBERS.fields_by_name['group']._options = None
_REQUESTLOADMEMBERS.fields_by_name['limit']._options = None
_REQUESTLOADMEMBERS.fields_by_name['next']._options = None
_REQUESTLOADMEMBERS._options = None
_RESPONSELOADMEMBERS.fields_by_name['cursor']._options = None
_RESPONSELOADMEMBERS.fields_by_name['members']._options = None
_RESPONSELOADMEMBERS._options = None
_UPDATEGROUPTITLECHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPTITLECHANGED.fields_by_name['title']._options = None
_UPDATEGROUPAVATARCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPAVATARCHANGED.fields_by_name['avatar']._options = None
_UPDATEGROUPABOUTCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPABOUTCHANGED.fields_by_name['about']._options = None
_UPDATEGROUPOWNERCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPOWNERCHANGED.fields_by_name['user_id']._options = None
_UPDATEGROUPBASEPERMISSIONSCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPBASEPERMISSIONSCHANGED.fields_by_name['base_permissions']._options = None
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['members']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['removed_users']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['added_members']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['members_count']._options = None
_UPDATEGROUPMEMBERSCOUNTCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSCOUNTCHANGED.fields_by_name['members_count']._options = None
_REQUESTCREATEGROUP.fields_by_name['rid']._options = None
_REQUESTCREATEGROUP.fields_by_name['title']._options = None
_REQUESTCREATEGROUP.fields_by_name['users']._options = None
_REQUESTCREATEGROUP.fields_by_name['group_type']._options = None
_REQUESTCREATEGROUP.fields_by_name['username']._options = None
_REQUESTCREATEGROUP.fields_by_name['optimizations']._options = None
_REQUESTCREATEGROUP.fields_by_name['base_permissions']._options = None
_REQUESTCREATEGROUP._options = None
_RESPONSECREATEGROUP._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['rid']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['title']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPTITLE._options = None
_REQUESTSETGROUPSHORTNAME.fields_by_name['peer']._options = None
_REQUESTSETGROUPSHORTNAME.fields_by_name['shortname']._options = None
_REQUESTSETGROUPSHORTNAME._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['rid']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['file_location']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPAVATAR._options = None
_RESPONSEEDITGROUPAVATAR._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['group_peer']._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['rid']._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['optimizations']._options = None
_REQUESTREMOVEGROUPAVATAR._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['rid']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['about']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPABOUT._options = None
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['random_id']._options = None
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['granted_permissions']._options = None
_REQUESTEDITGROUPBASEPERMISSIONS.fields_by_name['revoked_permissions']._options = None
_REQUESTEDITGROUPBASEPERMISSIONS._options = None
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['group_peer']._options = None
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['user_peer']._options = None
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['granted_permissions']._options = None
_REQUESTEDITMEMBERPERMISSIONS.fields_by_name['revoked_permissions']._options = None
_REQUESTEDITMEMBERPERMISSIONS._options = None
_RESPONSEMEMBER._options = None
_REQUESTINVITEUSER.fields_by_name['group_peer']._options = None
_REQUESTINVITEUSER.fields_by_name['rid']._options = None
_REQUESTINVITEUSER.fields_by_name['user']._options = None
_REQUESTINVITEUSER.fields_by_name['optimizations']._options = None
_REQUESTINVITEUSER._options = None
_REQUESTLEAVEGROUP.fields_by_name['group_peer']._options = None
_REQUESTLEAVEGROUP.fields_by_name['rid']._options = None
_REQUESTLEAVEGROUP.fields_by_name['optimizations']._options = None
_REQUESTLEAVEGROUP._options = None
_REQUESTKICKUSER.fields_by_name['group_peer']._options = None
_REQUESTKICKUSER.fields_by_name['rid']._options = None
_REQUESTKICKUSER.fields_by_name['user']._options = None
_REQUESTKICKUSER.fields_by_name['optimizations']._options = None
_REQUESTKICKUSER._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['group_peer']._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['user_peer']._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['permissions']._options = None
_REQUESTMAKEUSERADMIN._options = None
_GROUPMEMBERPERMISSION.fields_by_name['user_id']._options = None
_GROUPMEMBERPERMISSION.fields_by_name['permissions']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS.fields_by_name['group_id']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS.fields_by_name['user_ids']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS._options = None
_RESPONSEGETGROUPMEMBERPERMISSIONS._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['user_id']._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['permissions']._options = None
_REQUESTTRANSFEROWNERSHIP.fields_by_name['group_peer']._options = None
_REQUESTTRANSFEROWNERSHIP.fields_by_name['new_owner']._options = None
_REQUESTTRANSFEROWNERSHIP._options = None
_RESPONSEINVITEURL._options = None
_REQUESTGETGROUPINVITEURL.fields_by_name['group_peer']._options = None
_REQUESTGETGROUPINVITEURL._options = None
_REQUESTGETGROUPINVITEURLBASE._options = None
_RESPONSEGETGROUPINVITEURLBASE._options = None
_REQUESTREVOKEINVITEURL.fields_by_name['group_peer']._options = None
_REQUESTREVOKEINVITEURL._options = None
_REQUESTJOINGROUP.fields_by_name['token']._options = None
_REQUESTJOINGROUP.fields_by_name['optimizations']._options = None
_REQUESTJOINGROUP._options = None
_RESPONSEJOINGROUP._options = None
_REQUESTJOINGROUPBYPEER.fields_by_name['peer']._options = None
_REQUESTJOINGROUPBYPEER._options = None
_REQUESTDELETEGROUP.fields_by_name['group_id']._options = None
_REQUESTDELETEGROUP._options = None
_REQUESTGETGROUPPARTIALINFO.fields_by_name['token']._options = None
_REQUESTGETGROUPPARTIALINFO._options = None
_UPDATEGROUPMEMBERINVITED.fields_by_name['group_id']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['rid']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['invite_uid']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['rid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['mid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['inviter_uid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['kicker_uid']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['members']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['title']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['about']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['avatar']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['shortname']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['uid']._options = None

_GROUPS = _descriptor.ServiceDescriptor(
  name='Groups',
  full_name='dialog.Groups',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=10991,
  serialized_end=13717,
  methods=[
  _descriptor.MethodDescriptor(
    name='LoadMembers',
    full_name='dialog.Groups.LoadMembers',
    index=0,
    containing_service=None,
    input_type=_REQUESTLOADMEMBERS,
    output_type=_RESPONSELOADMEMBERS,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Groups/LoadMembers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateGroup',
    full_name='dialog.Groups.CreateGroup',
    index=1,
    containing_service=None,
    input_type=_REQUESTCREATEGROUP,
    output_type=_RESPONSECREATEGROUP,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Groups/CreateGroup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupTitle',
    full_name='dialog.Groups.EditGroupTitle',
    index=2,
    containing_service=None,
    input_type=_REQUESTEDITGROUPTITLE,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=b'\202\323\344\223\002#\"\036/v1/grpc/Groups/EditGroupTitle:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetGroupShortname',
    full_name='dialog.Groups.SetGroupShortname',
    index=3,
    containing_service=None,
    input_type=_REQUESTSETGROUPSHORTNAME,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Groups/SetGroupShortname:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupAvatar',
    full_name='dialog.Groups.EditGroupAvatar',
    index=4,
    containing_service=None,
    input_type=_REQUESTEDITGROUPAVATAR,
    output_type=_RESPONSEEDITGROUPAVATAR,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Groups/EditGroupAvatar:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveGroupAvatar',
    full_name='dialog.Groups.RemoveGroupAvatar',
    index=5,
    containing_service=None,
    input_type=_REQUESTREMOVEGROUPAVATAR,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Groups/RemoveGroupAvatar:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupAbout',
    full_name='dialog.Groups.EditGroupAbout',
    index=6,
    containing_service=None,
    input_type=_REQUESTEDITGROUPABOUT,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=b'\202\323\344\223\002#\"\036/v1/grpc/Groups/EditGroupAbout:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupBasePermissions',
    full_name='dialog.Groups.EditGroupBasePermissions',
    index=7,
    containing_service=None,
    input_type=_REQUESTEDITGROUPBASEPERMISSIONS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002-\"(/v1/grpc/Groups/EditGroupBasePermissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InviteUser',
    full_name='dialog.Groups.InviteUser',
    index=8,
    containing_service=None,
    input_type=_REQUESTINVITEUSER,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Groups/InviteUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveGroup',
    full_name='dialog.Groups.LeaveGroup',
    index=9,
    containing_service=None,
    input_type=_REQUESTLEAVEGROUP,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Groups/LeaveGroup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KickUser',
    full_name='dialog.Groups.KickUser',
    index=10,
    containing_service=None,
    input_type=_REQUESTKICKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1/grpc/Groups/KickUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MakeUserAdmin',
    full_name='dialog.Groups.MakeUserAdmin',
    index=11,
    containing_service=None,
    input_type=_REQUESTMAKEUSERADMIN,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Groups/MakeUserAdmin:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupMemberPermissions',
    full_name='dialog.Groups.GetGroupMemberPermissions',
    index=12,
    containing_service=None,
    input_type=_REQUESTGETGROUPMEMBERPERMISSIONS,
    output_type=_RESPONSEGETGROUPMEMBERPERMISSIONS,
    serialized_options=b'\202\323\344\223\002.\")/v1/grpc/Groups/GetGroupMemberPermissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditMemberPermissions',
    full_name='dialog.Groups.EditMemberPermissions',
    index=13,
    containing_service=None,
    input_type=_REQUESTEDITMEMBERPERMISSIONS,
    output_type=_RESPONSEMEMBER,
    serialized_options=b'\202\323\344\223\002*\"%/v1/grpc/Groups/EditMemberPermissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransferOwnership',
    full_name='dialog.Groups.TransferOwnership',
    index=14,
    containing_service=None,
    input_type=_REQUESTTRANSFEROWNERSHIP,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Groups/TransferOwnership:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupInviteUrl',
    full_name='dialog.Groups.GetGroupInviteUrl',
    index=15,
    containing_service=None,
    input_type=_REQUESTGETGROUPINVITEURL,
    output_type=_RESPONSEINVITEURL,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Groups/GetGroupInviteUrl:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupInviteUrlBase',
    full_name='dialog.Groups.GetGroupInviteUrlBase',
    index=16,
    containing_service=None,
    input_type=_REQUESTGETGROUPINVITEURLBASE,
    output_type=_RESPONSEGETGROUPINVITEURLBASE,
    serialized_options=b'\202\323\344\223\002*\"%/v1/grpc/Groups/GetGroupInviteUrlBase:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeInviteUrl',
    full_name='dialog.Groups.RevokeInviteUrl',
    index=17,
    containing_service=None,
    input_type=_REQUESTREVOKEINVITEURL,
    output_type=_RESPONSEINVITEURL,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Groups/RevokeInviteUrl:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinGroup',
    full_name='dialog.Groups.JoinGroup',
    index=18,
    containing_service=None,
    input_type=_REQUESTJOINGROUP,
    output_type=_RESPONSEJOINGROUP,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1/grpc/Groups/JoinGroup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinGroupByPeer',
    full_name='dialog.Groups.JoinGroupByPeer',
    index=19,
    containing_service=None,
    input_type=_REQUESTJOINGROUPBYPEER,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Groups/JoinGroupByPeer:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGroup',
    full_name='dialog.Groups.DeleteGroup',
    index=20,
    containing_service=None,
    input_type=_REQUESTDELETEGROUP,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Groups/DeleteGroup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupPartialInfo',
    full_name='dialog.Groups.GetGroupPartialInfo',
    index=21,
    containing_service=None,
    input_type=_REQUESTGETGROUPPARTIALINFO,
    output_type=_GROUPPARTIALINFO,
    serialized_options=b'\202\323\344\223\002)\"$/v1/grpc/Groups/GetGrpoupPartialInfo:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUPS)

DESCRIPTOR.services_by_name['Groups'] = _GROUPS

# @@protoc_insertion_point(module_scope)
